#!/usr/bin/env bash

OVERRIDE=false
OUTPUT='res-rs.dat'
GRAPHFILE='graph-rs.png'
NOPLOT=false

while test $# -gt 0; do
    case "$1" in
        -h|--help)
                echo "run_pfi - generates the optimal saving pattern for risk-sensitive preferences in Bommier and LeGrand, 2017."
                echo "          compiles, runs the fortran program; plots the graph using gnuplot and displays it using ristretto."
                echo " "
                echo "run_pfi [options] application [arguments]"
                echo " "
                echo "options:"
                echo "-h, --help                show brief help"
                echo "-f                        overrides any previous result file (NO SAVING)"
                echo "-np                       does not plot results"
                echo "-o FILENAME, --output=FILENAME     specifies the output file for results"
                echo "-g FILENAME, --graph=FILENAME      specifies the file for graphics (png no matter what!)"
                exit 0
                ;;
        -f)
                shift
                export OVERRIDE=true
                ;;
        -np)
                shift
                export NOPLOT=true
                ;;
        -o)
                shift
                if  ! test $# -gt 0 ; then
                        echo "no output file specified"
                        exit 1
                else
                    export OUTPUT=`echo $1 | sed -e 's/^[^=]*=//g'`
                fi
                shift
                ;;
        --output*)
                export OUTPUT=`echo $1 | sed -e 's/^[^=]*=//g'`
                shift
                ;;
        -g)
            shift
            if  ! test $# -gt 0 ; then
                echo "no output file specified"
                exit 1
            else
                export GRAPHFILE=`echo $1 | sed -e 's/^[^=]*=//g'`
            fi
            shift
            ;;
        --graph*)
            export GRAPHFILE=`echo $1 | sed -e 's/^[^=]*=//g'`
            shift
            ;;
        *)
            break
            ;;
    esac
done

rm rs-pfi *.mod 2> /dev/null

REPLY=false
if [ -f ./"$OUTPUT" ] && [ "$OVERRIDE" == false ]; then
    echo "The result file already exists."
    while [ "$REPLY" == false ]; do
        read -p "Rerun the whole program and overwrite the result file? (y/n) " yn
        case $yn in
            [Yy]* ) 
                REPLY=true
                OVERRIDE=true
                ;;
            [Nn]* ) 
                echo "results not deleted"
                OVERRIDE=false
                REPLY=true
                ;;
            * ) echo "Please answer yes or no.";;
        esac
    done 
fi

if ! [ -f ./"$OUTPUT" ]; then
    gfortran -o rs-pfi mod_myfzero.f90 mod_tools.f90 mod_params.f90 mod_vars.f90 mod_myinterp1.f90 prec-savings-rs-pfi.f90 && ./rs-pfi || exit 1
elif [ "$OVERRIDE" == true ]; then
    gfortran -o rs-pfi mod_myfzero.f90 mod_tools.f90 mod_params.f90 mod_vars.f90 mod_myinterp1.f90 prec-savings-rs-pfi.f90 && ./rs-pfi || exit 1
fi

mv res-rs.dat "$OUTPUT" 2> /dev/null


if [ "$NOPLOT" == false ]; then
    GNUPLOT_OK=$(dpkg-query -W --showformat='${Status}\n' gnuplot*|grep "install ok installed")
    if [ "" == "$GNUPLOT_OK" ]; then
      echo "Package gnuplot is not installed. Results are not plotted"
      echo "Results are stored in res-pfi.dat. They can be plotted with any method of your choice."
      echo "Otherwise install gnuplot and re-run this script (without deleting the result file)"
    else
      gnuplot -e "filename='$OUTPUT'; graphname='$GRAPHFILE'; prefs='Risk-sensitive'" plot.plt
    fi

    RISTRETTO_OK=$(dpkg-query -W --showformat='${Status}\n' ristretto|grep "install ok installed")
    if [ "" == "$RISTRETTO_OK" ]; then
      echo "Package ristretto is not installed. Graph is not plotted"
      echo "Graph can be displayed with any package of your choice."
    else
        ristretto "$GRAPHFILE" 2> /dev/null
    fi
fi
